[
    "onion",
    "tomato",
    "carrot",
    "potato",
    "zucchini",
    "spinach",
    "cucumber",
    "chive",
    "cabbage",
    "eggplant",
    "leek",
    "lettuce",
    "asparagus",
    "vegetable",
    "tomatillo",
    "radish",
    "parsnip",
    "beet",
    "turnip",
    "okra",
    "kale",
    "arugula",
    "jicama",
    "rhubarb",
    "rutabaga",
    "aubergine",
    "courgette",
    "arrowroot",
    "escarole",
    "beetroot",
    "gherkin",
    "tapioca",
    "wasabi",
    "yam",
    "radicchio",
    "capsicum",
    "kumara",
    "stevia",
    "celeriac",
    "swede",
    "endive",
    "mesclun",
    "cassava",
    "chayote",
    "frisee",
    "brinjal",
    "cornichons",
    "kohlrabi",
    "fiddlehead",
    "rapini",
    "daikon",
    "tomatoe",
    "bottlegourd",
    "marrow",
    "ramp",
    "chard",
    "karela",
    "tatsoi",
    "kucai",
    "mirliton",
    "mizuna",
    "ube",
    "vidalia",
    "yuca",
    "yucca",
]
