grape_pool = [
    "Sauvignon Blanc",
    "Muscadelle",
    "Pinot Gris",
    "Riesling",
    "Albariño",
    "Chardonnay",
    "Garganega",
    "Fiano",
    "Pinot Meunier",
    "Viognier",
    "Grecanico",
    "Verdejo",
    "Grenache Blanc",
    "Malvasia",
    "Grüner Veltliner",
    "Merlot",
    "Corvina",
    "Zweigelt",
    "Chenin Blanc",
    "Molinara",
    "Rondinella",
    "Arneis",
    "Pinot Noir",
    "Cabernet Franc",
    "Cabernet Sauvignon",
    "Petit Verdot",
    "Nebbiolo",
    "Tempranillo",
    "Barbera",
    "Sangiovese",
    "Cannonau",
    "Carignan",
    "Torrontés",
    "Savagnin",
    "Carricante",
    "Catarratto",
    "Falanghina",
    "Zibibbo",
    "Sylvaner",
    "Pinot Blanc",
    "Pecorino",
    "Verdicchio",
    "Macabeo",
    "Ribolla Gialla",
    "Trebbiano",
    "Tannat",
    "Marsanne",
    "Vilana",
    "Shiraz",
    "Grenache Noir",
    "Syrah",
    "Caladoc",
    "Castelão",
    "Tinta Roriz",
    "Alicante Bouschet",
    "Touriga Nacional",
    "Verdelho",
    "Antão Vaz",
    "Pinot Grigio",
    "Petit Manseng",
    "Gros Manseng",
    "Colorino",
    "Malbec",
    "Carmenère",
    "Monastrell",
    "Garnacha",
    "Grillo",
    "Tinta Barroca",
    "Cinsault",
    "Perricone",
    "Mourvèdre",
    "Pinotage",
    "Montepulciano",
    "Negroamaro",
    "Cabernet",
    "Zinfandel",
    "Moscato",
    "Arinto",
    "Grenache",
    "Fernão Pires",
    "Airén",
    "Dornfelder",
    "Rivaner",
    "Bobal",
    "Cortese",
    "Colombard",
    "Bonarda",
    "Teroldego",
    "Petite Sirah",
    "Graciano",
    "Primitivo",
    "Müller-Thurgau",
    "Welschriesling",
    "Trincadeira",
    "Muscat",
    "Ruby Cabernet",
    "Marselan",
    "Touriga Franca",
    "Agiorgitiko",
    "Roussanne",
    "Sauvignon Gris",
    "Alfrocheiro",
    "Viosinho",
    "Moscatel",
    "Viura",
    "Ugni Blanc",
    "Silvaner",
    "Tinta Miúda",
    "Lambrusco",
    "Nero di Troia",
    "Roupeiro",
    "Malvasia Nera",
    "Poulsard",
    "Nosiola",
    "Traminer",
    "Azal",
    "Loureiro",
    "Trajadura",
    "Furmint",
    "Romeiko",
    "Neuburger",
    "Bouvier",
    "Glera",
    "Sercial",
    "Assyrtiko",
    "Scheurebe",
    "Sárga Muskotály",
    "Pedro Ximénez",
    "Weissburgunder",
    "Grechetto",
    "Tinta Amarela",
    "Spätburgunder",
    "Vidal",
    "Gouveio",
    "Rabigato",
    "Petit Courbu",
    "Rieslaner",
    "Inzolia",
    "Blaufränkisch",
    "Huxelrebe",
    "Kékfrankos",
    "Kadarka",
    "Trousseau",
    "Saperavi",
    "Blauburger",
    "Dolcetto",
    "Canaiolo",
    "Nerello Mascalese",
    "Nerello Cappuccio",
    "Xynomavro",
    "Refosco",
    "Trollinger",
    "Mazuelo",
    "Bical",
    "Gamay",
    "Gaglioppo",
    "Manto Negro",
    "Callet",
    "Counoise",
    "Baga",
    "Brachetto",
    "Portugieser",
    "Lagrein",
    "Frappato",
    "Alicante",
    "Jaen",
    "Ciliegiolo",
    "Rufete",
    "Vernatsch",
    "País",
    "Kalecik Karasi",
    "Raboso",
    "Limnio",
    "Marzemino",
    "Mataro",
    "Aglianico",
    "Plavac Mali",
    "Croatina",
    "Vespolina",
    "Freisa",
    "Durif",
    "Tinto Fino",
    "Sagrantino",
    "Mandilaria",
    "Moreto",
    "Garnacha Blanca",
    "Bourboulenc",
    "Muscardin",
    "Tinta Pinheira",
    "Rubired",
    "Magliocco",
    "Cesanese",
    "Öküzgözü",
    "Mavrud",
    "Melnik",
    "Schioppettino",
    "Pinot Nero",
    "Cabernet Dorsa",
    "Abouriou",
    "Sousão",
    "Pedral",
    "Schiava",
    "Clairette",
    "Rubin",
    "Feteasca Neagra",
    "Monica",
    "Groppello",
    "Aramon",
    "Blauer Wildbacher",
    "Sciaccarello",
    "Nielluccio",
    "Vermentino",
    "Rolle",
    "Tibouren",
    "Piedirosso",
    "Blauburgunder",
    "Espadeiro",
    "Grolleau",
    "Parellada",
    "Mondeuse",
    "Trebbiano di Lugana",
    "Lemberger",
    "Negrette",
    "Piquepoul",
    "Prugnolo Gentile",
    "Auxerrois",
    "Mauzac",
    "Aligoté",
    "Meunier",
    "Maria Gomes",
    "Muskateller",
    "Reichensteiner",
    "Malagousia",
    "Cerceal",
    "Rkatsiteli",
    "Chinebuli",
    "Moscato Bianco di Canelli",
    "Verduzzo",
    "Moschofilero",
    "Merseguera",
    "Seyval Blanc",
    "Erbaluce",
    "Folle Blanche",
    "Friulano",
    "Greco",
    "Emir",
    "Treixadura",
    "Godello",
    "Misket",
    "Avesso",
    "Pedernã",
    "Feteasca Regala",
    "Narince",
    "Kerner",
    "Bacchus",
    "Rebula",
    "Olaszrizling",
    "Arrufiac",
    "Roter Veltliner",
    "Savatiano",
    "Kéknyelü",
    "Melon de Bourgogne",
    "Favorita",
    "Romorantin",
    "Chasselas",
    "Merwah",
    "Timorasso",
    "Bombino Bianco",
    "Chiavennasca",
    "Juhfark",
    "Alvarinho",
    "Kangun",
    "Irsai Olivér",
    "Ezerjó",
    "Xynisteri",
    "Koshu",
    "Mission",
    "Prieto Picudo",
    "Cabernet Gernischt",
    "Bastardo",
    "Vranac",
    "Prokupac",
    "Cococciola",
    "Pansa Blanca",
    "Bastard Negre",
    "Verdello",
    "Drupeggio",
    "Malvazija Istarska",
    "Mtsvane",
    "Grauburgunder",
    "Moscatel de Grano Menudo",
    "Albillo",
    "Encruzado",
    "Ehrenfelser",
    "Barcelo",
    "Zierfandler",
    "Rotgipfler",
    "Ortega",
    "Albana",
    "Elbling",
    "Vespaiola",
    "Jacquère",
    "Vernaccia",
    "Segalin",
    "Perle",
    "Smederevka",
    "Chancellor",
    "Len de l'El",
    "Seibel",
    "Acikara",
    "Spourtiko",
    "Charbono",
    "Ormeasco",
    "Lexia",
    "Fié Gris",
    "Sultana",
    "Ottavianello",
    "Listán Blanco",
    "Petite Arvine",
    "Flora",
    "Listrão",
    "Phoenix",
    "Spanna",
    "Aleatico",
    "Szürkebarát",
    "Pamid",
    "Picolit",
    "Talia",
    "Papazkarasi",
    "Lledoner Pelut",
    "Pigato",
    "Frühroter Veltliner",
    "St Laurent",
    "Tamâioasa Româneasca",
    "Concord",
    "Parraleta",
    "Magaratch Ruby",
    "Pinot Beurot",
    "Süssschwarz",
    "Tamyanka",
    "Galego Dourado",
    "Ten Göynek",
    "Aragonês",
    "Cot",
    "Pelaverga",
    "Malvasía Aromática",
    "Taminga",
    "Terret Bourret",
    "Couderc Noir",
    "Periquita",
    "Baco Blanc",
    "Malvasia Cândida",
    "Areni Noir",
    "Terret Gris",
    "Mammolo",
    "Baiyu",
    "Malvasia Manresana",
    "Tarrango",
    "Gewurztraminer",
    "Aspiran",
    "Criolla Chica",
    "Plantscher",
    "Babeasca Neagra",
    "Tokay d'Alsace",
    "Crljenak Kaštelanski",
    "Manseng Noir",
    "Baroque",
    "Malvoisie",
    "Teran",
    "Prosecco",
    "Torbato",
    "Babic",
    "Biancu",
    "Goldberger",
    "Baco Noir",
    "De Chaunac",
    "Pignolo",
    "Maratheftiko",
    "Marmajuelo",
    "Rachuli Mtsvane",
    "Gordo",
    "Delaware",
    "Pineau d'Aunis",
    "Maréchal Foch",
    "Boal",
    "Ranina",
    "Gouais Blanc",
    "Barbarossa",
    "Pinenc",
    "Räuschling",
    "Domina",
    "Meksassi",
    "Borrado das Moscas",
    "Tinta Cão",
    "Grasa",
    "Tinta Carvalha",
    "Regner",
    "Graševina",
    "Tresallier",
    "Dunkelfelder",
    "Mavro",
    "Menu Pineau",
    "Tsulukidze Tetra",
    "Berligou",
    "Mavrodaphne",
    "Carignan Blanc",
    "Tinta Negra",
    "Rhine Riesling",
    "Dzelshavi",
    "Black Muscat",
    "Piñuelo",
    "Rhoditis",
    "Vasilissa",
    "Minutolo",
    "Etraire de l'Aduï",
    "Portan",
    "Cayetana Blanca",
    "Tintilia",
    "Evmolpia",
    "Melnik 55",
    "Blauer Arbst",
    "Molette",
    "Cayuga White",
    "Fer Servadou",
    "Mencía",
    "Blauer Frühburgunder",
    "Mondeuse Blanche",
    "Riesling Italico",
    "Grolleau Gris",
    "Blauer Spätburgunder",
    "Pressac",
    "Morava",
    "Cereza",
    "Fogoneu",
    "Morillon",
    "Chardonel",
    "Tribidrag",
    "Rizling",
    "Gros Plant",
    "Franconia",
    "Morio-Muskat",
    "Fränkischer Burgunder",
    "Modra Frankinja",
    "Chasan",
    "Robola",
    "Gutedel",
    "Frankovka",
    "Modri Pinot",
    "Gutenborner",
    "Ull de Llebre",
    "Rollo",
    "Hanepoot",
    "Mollard",
    "Braquet",
    "Ramisco",
    "Chevrier",
    "Uva Rara",
    "Hárslevelu",
    "Villard Blanc",
    "Frühburgunder",
    "Breton",
    "Vaccarèse",
    "Heida",
    "Refosco di Faedis",
    "Brocol",
    "Mtsvivani Kakhuri",
    "Valdiguié",
    "Himbertscha",
    "Brunello",
    "Completer",
    "Vavrinecke",
    "Humagne",
    "Gamay del Trasimeno",
    "Rondo",
    "Burgund Mare",
    "Voskeat",
    "Gamé",
    "Morellino",
    "Rossese",
    "Criolla Grande",
    "Roussette",
    "Hüyük  Ak Üzümü",
    "Gamza",
    "Rouchet",
    "Crouchen",
    "Ruländer",
    "Villard Noir",
    "Gänsfüsser",
    "Weisser Riesling",
    "Moristel",
    "Royalty",
    "Debina",
    "Muskotály",
    "Sacy",
    "Morrastel",
    "Dimyat",
    "Sämling 88",
    "Italian Riesling",
    "Garrut",
    "Xarello",
    "Moshomavro",
    "Dinka",
    "Mourisco Tinto",
    "Niagara",
    "Cabernet Severny",
    "Jaén Blanca",
    "Grand Noir de la Calmette",
    "Zalema",
    "Ruen",
    "Johannisberg",
    "White",
    "Zeleni Silvanec",
    "Müllerebe",
    "Nuragus",
    "Sauvignon Vert",
    "Grignolino",
    "Agrippiotis",
    "Emerald Riesling",
    "Muscat Hamburg",
    "Salvador",
    "Ondenc",
    "Karlovo Misket",
    "Alarije",
    "Zilavka",
    "Samsó",
    "Optima",
    "Carcajolo Nero",
    "Harriague",
    "Albalonga",
    "Samtrot",
    "Negramoll",
    "Orémus",
    "Helfensteiner",
    "Schönburger",
    "Esgana",
    "Carignan Noir",
    "Heroldrebe",
    "Scuppernong",
    "Királeányka",
    "Palomino Fino",
    "Isabella",
    "Semillon",
    "Brachetto d'Acqui",
    "Kizil Üzüm",
    "Faber",
    "Carnelian",
    "Klevner",
    "Pardina",
    "João de Santarém",
    "Altesse",
    "Nero d'Avola",
    "Schwarzblauer Riesling",
    "Catawba",
    "Jurançon Noir",
    "Siegerrebe",
    "Laški",
    "Schwarzriesling",
    "Fendant",
    "Cencibel",
    "Amigne",
    "Laški Rizling",
    "Schwarzurban",
    "Centurian",
    "Ansonica",
    "Šipon",
    "Moscato Bianco",
    "Leányka",
    "Norton",
    "Feteasca Alba",
    "Karmrahyut",
    "Chambourcin",
    "Acıkara",
    "Băbească Neagră",
    "Babić",
    "Fetească Neagră",
    "Kalecik Karası",
    "Fetească Alba",
    "Fetească Regală",
    "Grasă",
    "Hárslevelű",
    "Kızıl Üzüm",
    "Tămâioasă Românească",
]

subregion_pool = [
    "Hunter’s Valley",
    "Kamptal",
    "Toro",
    "Soave",
    "Yarra Valley",
    "Vinho Verde",
    "Elgin",
    "Sauternes",
    "Kremstal",
    "Chianti",
    "Ribera del Duero",
    "Riais Baixas",
    "Geelong",
    "Walker Bay",
    "Barossa Valley",
    "Weinvertel",
    "Brunello di Montalcino",
    "Bierzo",
    "Wairarapa",
    "Macedon Ranges",
    "Swartland",
    "Languedoc",
    "Eden Valley",
    "Carnumtum",
    "Vino Nobile di Monteulciano",
    "Howkes Bay",
    "Napa County",
    "Napa Valley",
    "Rutherglen",
    "Paarl",
    "Jeres",
    "Roussillon",
    "Adelaide Hills",
    "Super Tuscan",
    "Cava",
    "Sonoma Count",
    "Stellenbosch",
    "Malaga",
    "Northern Rhône",
    "McLaren Vale",
    "Graves",
    "Peñedes",
    "Dão",
    "Mendocino Country",
    "Margaret River",
    "Constantia",
    "Southern Rhône",
    "Coonawarra",
    "Médoc",
    "Amarone della Valpolicella",
    "Priorat",
    "Bairrada",
    "Barolo",
    "Rueda",
    "Libournais",
    "Valpolicella",
    "Wachau",
    "Barbaresco",
    "Argentina",
    "Mornington Peninsula",
    "Barossa",
    "Clare Valley",
    "Serra Gaucha",
    "niagara peninsula",
    "Okanagan Valley",
    "Valle Central",
    "Chablis",
    "Côte de Nuits",
    "Côte de Beaune",
    "Côte Chalonnaise",
    "Maconnais",
    "Vino Nobile di Montepulciano",
    "Hawkes Bay",
    "Nelson",
    "Marlborough",
    "Central Otago",
    "Beira Interior",
    "Coastal Region",
    "Breede River Valley",
    "Cape South Coast",
    "Klein Karoo",
    "Olifant River",
    "Sonoma County",
    "Mendocino County",
]

region_pool = [
    "Sardinia",
    "Rheinhessen",
    "Valencia",
    "Israel",
    "Provence",
    "Ontario",
    "Minho",
    "Morocco",
    "Argentina",
    "Castila la Mancha",
    "Toscana",
    "Pflaz",
    "Valais",
    "Abbruzo",
    "Corse",
    "Nova Scotia",
    "Tejo",
    "North Island",
    "New South Wales",
    "Catalunya",
    "Trentino Alto Adige",
    "Nahe",
    "Basilicata",
    "Languedoc Roussillon",
    "British Columbia",
    "South Island",
    "Queenland",
    "Galicia",
    "Umbria",
    "Franken",
    "Turkey",
    "Calabria",
    "Loire Valley",
    "Azores",
    "Nelson",
    "Tasmania",
    "Valle d'Aosta",
    "Balearic Islands",
    "Baden",
    "Ukraine",
    "Campania",
    "Rhône Valley",
    "Chile",
    "Romania",
    "Marlborough",
    "Victoria",
    "Sicily",
    "Canary Islands",
    "United Kingdom",
    "Emilia Romagna",
    "Savoie",
    "China",
    "Russian Federation",
    "Central Otago",
    "South Australia",
    "Navarra",
    "Macedonia",
    "Uruguay",
    "Friuli Venezia Giulia",
    "Jura",
    "Croatia",
    "Slovenia",
    "Western Australia",
    "Rioja",
    "Peloponnese",
    "Veneto",
    "California",
    "Lazio",
    "Cyprus",
    "Costal Region",
    "Alentejo",
    "Lower Austria",
    "Extremandura",
    "Santorini",
    "Japan",
    "Washington",
    "Liguria",
    "Alsace",
    "South West",
    "Cape South Coast",
    "Beiras",
    "Vien",
    "Murcia",
    "Oregon",
    "Lebanon",
    "Beaujolais",
    "Lombardia",
    "Burgenland",
    "Levante",
    "Tokaj",
    "New York",
    "Mexico",
    "Bordeaux",
    "Douro",
    "Marche",
    "Andalucia",
    "Stryia",
    "Aragon",
    "Burgundy",
    "Moldova, Republic of",
    "Lisboa",
    "Piemonte",
    "Castilla y Leon",
    "Brazil",
    "India",
    "Champagne",
    "Madeira",
    "Puglia",
    "Bulgaria",
    "Georgia",
    "Mosel Saar Rüwer",
    "Ahr",
    "Rheingau",
    "Terras do Dao",
    "Beira Atlantico",
    "Terras de Cister",
    "Terras da Beira",
    "Western Cape",
]
